@@ -40,13 +40,13 @@ class JabberEditAccountWidget: public QWidget, public Ui::DlgJabberEditAccountWi
 Q_OBJECT
 
 public:
-	JabberEditAccountWidget (JabberProtocol * proto, JabberAccount *, QWidget * parent = 0);
+	JabberEditAccountWidget (JabberProtocol * proto, JabberAccount *, QWidget * parent = nullptr);
 	~JabberEditAccountWidget ();
-	virtual bool validateData ();
-	virtual Kopete::Account *apply ();
+	bool validateData () Q_DECL_OVERRIDE;
+	Kopete::Account *apply () Q_DECL_OVERRIDE;
 	JabberAccount *account ();
 
-private slots:
+private Q_SLOTS:
 	void registerClicked ();
 	void slotChangePasswordClicked ();
 	void slotChangePasswordFinished ();
